==> jnats-2.17.6-sources.jar: io/nats/client/JetStreamApiException.java <==
// Copyright 2020 The NATS Authors
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at:
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package io.nats.client;

import io.nats.client.api.ApiResponse;
import io.nats.client.api.Error;

/**
 * JetStreamApiException is used to indicate that the server returned an error while make a request
 * related to JetStream.
 */
public class JetStreamApiException extends Exception {
    private final Error error;

    /**
     * Construct an exception with the response from the server.
     *
     * @param apiResponse the response from the server.
     */
    public JetStreamApiException(ApiResponse<?> apiResponse) {
        this(apiResponse.getErrorObject());
    }

    public JetStreamApiException(Error error) {
        super(error.toString());
        this.error = error;
    }

    /**
     * Get the error code from the response
     *
     * @return the code
     */
    public int getErrorCode() {
        return error.getCode();
    }

    /**
     * Get the error code from the response
     *
     * @return the code
     */
    public int getApiErrorCode() {
        return error.getApiErrorCode();
    }

    /**
     * Get the description from the response
     *
     * @return the description
     */
    public String getErrorDescription() {
        return error.getDescription();
    }
}

==> jnats-2.24.0-sources.jar: io/nats/client/JetStreamApiException.java <==
// Copyright 2020 The NATS Authors
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at:
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package io.nats.client;

import io.nats.client.api.ApiResponse;
import io.nats.client.api.Error;
import org.jspecify.annotations.NonNull;

/**
 * JetStreamApiException is used to indicate that the server returned an error while make a request
 * related to JetStream.
 */
public class JetStreamApiException extends Exception {
    /**
     * The error that this exception represents if there is one
     */
    private final Error error;

    /**
     * @deprecated Prefer to construct with JetStreamApiException(@NonNull Error)
     * Construct an exception with the response from the server.
     * @param apiResponse the response from the server.
     */
    @Deprecated
    public JetStreamApiException(ApiResponse<?> apiResponse) {
        // deprecated because of getErrorObject() is marked as @Nullable
        //noinspection DataFlowIssue
        this(apiResponse.getErrorObject());
    }

    /**
     * Construct an exception with an Error
     * @param error the error
     */
    public JetStreamApiException(@NonNull Error error) {
        super(error.toString());
        this.error = error;
    }

    /**
     * Get the error code from the response
     * @return the code
     */
    public int getErrorCode() {
        return error.getCode();
    }

    /**
     * Get the error code from the response
     * @return the code
     */
    public int getApiErrorCode() {
        return error.getApiErrorCode();
    }

    /**
     * Get the description from the response
     * @return the description
     */
    public String getErrorDescription() {
        return error.getDescription();
    }
}
